@@ -1,6 +1,6 @@
 /*
 qgvdial is a cross platform Google Voice Dialer
-Copyright (C) 2009-2012  Yuvraaj Kelkar
+Copyright (C) 2009-2013  Yuvraaj Kelkar
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
@@ -46,14 +46,16 @@ GVApi::getSystemProxies (QNetworkProxy &http, QNetworkProxy &https)
     do { // Begin cleanup block (not a loop)
         QList<QNetworkProxy> netProxies =
         QNetworkProxyFactory::systemProxyForQuery (
-        QNetworkProxyQuery(QUrl("http://www.google.com")));
-        http = netProxies[0];
-        if (QNetworkProxy::NoProxy != http.type ()) {
-            if (emitLog) {
-                Q_DEBUG("Got proxy: host = ") << http.hostName ()
-                               << ", port = " << http.port ();
+            QNetworkProxyQuery(QUrl("http://www.google.com")));
+        if (netProxies.count() != 0) {
+            http = netProxies[0];
+            if (QNetworkProxy::NoProxy != http.type ()) {
+                if (emitLog) {
+                    Q_DEBUG(QString("Got proxy: host = %1, port = %2")
+                            .arg(http.hostName ()).arg (http.port ()));
+                }
+                break;
             }
-            break;
         }
 
         // Otherwise Confirm it
@@ -86,14 +88,16 @@ GVApi::getSystemProxies (QNetworkProxy &http, QNetworkProxy &https)
     do { // Begin cleanup block (not a loop)
         QList<QNetworkProxy> netProxies =
         QNetworkProxyFactory::systemProxyForQuery (
-        QNetworkProxyQuery(QUrl("https://www.google.com")));
-        https = netProxies[0];
-        if (QNetworkProxy::NoProxy != https.type ()) {
-            if (emitLog) {
-                Q_DEBUG("Got proxy: host =") << https.hostName () << ", port = "
-                                             << https.port ();
+            QNetworkProxyQuery(QUrl("https://www.google.com")));
+        if (netProxies.count () != 0) {
+            https = netProxies[0];
+            if (QNetworkProxy::NoProxy != https.type ()) {
+                if (emitLog) {
+                    Q_DEBUG(QString("Got proxy: host = %1, port = %2")
+                            .arg(https.hostName ()).arg (https.port ()));
+                }
+                break;
             }
-            break;
         }
 
         // Otherwise Confirm it
@@ -114,7 +118,7 @@ GVApi::getSystemProxies (QNetworkProxy &http, QNetworkProxy &https)
             int port = strPort.toInt ();
 
             if (emitLog) {
-                Q_DEBUG("Found http proxy: ") << strHost << ":" << port;
+                Q_DEBUG("Found https proxy: ") << strHost << ":" << port;
             }
             https.setHostName (strHost);
             https.setPort (port);
@@ -399,24 +403,19 @@ GVApi::login(AsyncTaskToken *token)
     }
 
     if (loggedIn) {
+        if (rnr_se.isEmpty ()) {
+            Q_WARN("User was already logged in, but there is no rnr_se!");
+        } else if (emitLog) {
+            Q_DEBUG("User was already logged in...");
+        }
+
+        token->outParams["rnr_se"] = rnr_se;
         token->status = ATTS_SUCCESS;
         token->emitCompleted ();
         return true;
     }
 
-    QUrl url(GV_ACCOUNT_SERVICELOGIN);
-    return doLogin1 (url, token);
-}//GVApi::login
-
-bool
-GVApi::doLogin1(QUrl url, AsyncTaskToken *token)
-{
-    url.addQueryItem("nui"     , "5");
-    url.addQueryItem("service" , "grandcentral");
-    url.addQueryItem("ltmpl"   , "mobile");
-    url.addQueryItem("btmpl"   , "mobile");
-    url.addQueryItem("passive" , "true");
-    url.addQueryItem("continue", "https://www.google.com/voice/m");
+    QUrl url(GV_HTTP);
 
     bool rv =
     doGet(url, token, this,
@@ -424,7 +423,7 @@ GVApi::doLogin1(QUrl url, AsyncTaskToken *token)
     Q_ASSERT(rv);
 
     return rv;
-}//GVApi::doLogin1
+}//GVApi::login
 
 void
 GVApi::onLogin1(bool success, const QByteArray &response, QNetworkReply *,
@@ -453,14 +452,38 @@ GVApi::onLogin1(bool success, const QByteArray &response, QNetworkReply *,
             break;
         }
 
+        hiddenLoginFields.clear ();
         if (!parseHiddenLoginFields (strResponse, hiddenLoginFields)) {
             Q_WARN("Failed to parse hidden fields");
             success = false;
             break;
         }
 
+        QString nextAction;
+        QRegExp rxForm("<form.*>(.*)</form>");
+        rxForm.setMinimal(true);
+        int pos = strResponse.indexOf (rxForm);
+        while (-1 != pos) {
+            QString cap = rxForm.cap (0);
+            quint32 len = cap.length ();
+            QRegExp rxAction("action=\"(.*)\"");
+            rxAction.setMinimal (true);
+            if (cap.contains ("gaia_loginform") && cap.contains (rxAction)) {
+                nextAction = rxAction.cap (1);
+                break;
+            }
+
+            pos = strResponse.indexOf (rxForm, pos + len);
+        }
+
+        if (nextAction.isEmpty ()) {
+            Q_WARN("Failed to get login form");
+            success = false;
+            break;
+        }
+
         Q_DEBUG("Starting service login");
-        QUrl url(GV_ACCOUNT_SERVICELOGIN);
+        QUrl url(nextAction);
         success = postLogin (url, token);
     } while (0); // End cleanup block (not a loop)
 
@@ -542,6 +565,7 @@ gonext:
 bool
 GVApi::postLogin(QUrl url, AsyncTaskToken *token)
 {
+    QUrl content;
     QNetworkCookie galx;
     bool found = false;
 
@@ -562,30 +586,48 @@ GVApi::postLogin(QUrl url, AsyncTaskToken *token)
 
     QStringList keys;
     QVariantMap allLoginFields;
-    allLoginFields["passive"]     = "true";
-    allLoginFields["timeStmp"]    = "";
-    allLoginFields["secTok"]      = "";
-    allLoginFields["GALX"]        = galx.value ();
-    allLoginFields["Email"]       = token->inParams["user"];
-    allLoginFields["Passwd"]      = token->inParams["pass"];
-    allLoginFields["PersistentCookie"] = "yes";
-    allLoginFields["rmShown"]     = "1";
-    allLoginFields["signIn"]      = "Sign+in";
-
     keys = hiddenLoginFields.keys();
     foreach (QString key, keys) {
         allLoginFields[key] = hiddenLoginFields[key];
     }
 
+    if (!allLoginFields.contains ("Email")) {
+        allLoginFields["Email"] = token->inParams["user"];
+    }
+    if (!allLoginFields.contains ("Passwd")) {
+        allLoginFields["Passwd"] = token->inParams["pass"];
+    }
+    if (!allLoginFields.contains ("PersistentCookie")) {
+        allLoginFields["PersistentCookie"] = "yes";
+    }
+    if (!allLoginFields.contains ("passive")) {
+        allLoginFields["passive"] = "true";
+    }
+    if (!allLoginFields.contains ("timeStmp")) {
+        allLoginFields["timeStmp"] = "";
+    }
+    if (!allLoginFields.contains ("secTok")) {
+        allLoginFields["secTok"] = "";
+    }
+    if (!allLoginFields.contains ("GALX")) {
+        allLoginFields["GALX"] = galx.value ();
+    }
+    if (!allLoginFields.contains ("rmShown")) {
+        allLoginFields["rmShown"] = "1";
+    }
+    if (!allLoginFields.contains ("signIn")) {
+        allLoginFields["signIn"] = "Sign+in";
+    }
+
     keys = allLoginFields.keys();
     foreach (QString key, keys) {
         if (key != "dsh") {
-            url.addQueryItem(key, allLoginFields[key].toString());
+            content.addQueryItem(key, allLoginFields[key].toString());
         }
     }
 
     found =
-    doPostForm(url, url.encodedQuery(), token, this,
+    doPostForm(url, content.encodedQuery(), token, this,
                SLOT(onLogin2(bool,const QByteArray&,QNetworkReply*,void*)));
     Q_ASSERT(found);
 
@@ -600,7 +642,6 @@ GVApi::onLogin2(bool success, const QByteArray &response, QNetworkReply *reply,
     QString strResponse = response;
     bool accountConfigured = true;
     bool accountReviewRequested = false;
-    bool foreignUrl = false;
 
 #if 0
     QFile fTemp("login2.html");
@@ -616,166 +657,77 @@ GVApi::onLogin2(bool success, const QByteArray &response, QNetworkReply *reply,
             break;
         }
 
-        // There will be 2-3 moved temporarily redirects.
-        QUrl urlMoved = NwReqTracker::hasMoved(reply);
-        if (!urlMoved.isEmpty ()) {
-            QString dest = urlMoved.toString ();
-            if (dest.contains ("voice/help/setupMobile")) {
-                accountConfigured = false;
+        QUrl replyUrl = reply->url ();
+        QString strReplyUrl = replyUrl.toString();
+
+        // Check to see if 2 factor auth is expected or rquired.
+        if (!strReplyUrl.contains ("SmsAuth")) {
+            foreach (QNetworkCookie cookie, jar->getAllCookies ()) {
+                if (cookie.name() == "gvx") {
+                    loggedIn = true;
+                    break;
+                }
+            }
+
+            // If "gvx" was found, then we're logged in.
+            if (!loggedIn) {
                 success = false;
+
+                // Dump out cookie names
+                QString msg = "Cookie names: ";
+                QStringList cookieNames;
+                foreach (QNetworkCookie cookie, jar->getAllCookies ()) {
+                    cookieNames += cookie.name();
+                }
+                msg += cookieNames.join (", ");
+                Q_DEBUG(msg);
+
                 break;
             }
 
-            if (dest.contains ("AccountRecoveryOptions")) {
-                token->outParams["nextUrl"] = urlMoved;
-                accountReviewRequested = true;
-                success = false;
-                break;
-            }
-#if 0
-            if (emitLog) {
-                Q_DEBUG("Moved to") << dest;
-            }
-#endif
-
-            int foreign = 0;
-            if ((token->outParams.contains ("foreign")) &&
-                ((dest == GV_HTTPS_M) ||
-                  (foreign = token->outParams["foreign"].toInt()) > 0))
-            {
-                foreign++;
-                token->outParams["foreign"] = foreign;
-                success = doGet(urlMoved, token, this,
-                   SLOT(onLogin2(bool,const QByteArray&,QNetworkReply*,void*)));
-            } else {
-                success = postLogin (urlMoved, token);
-            }
+            success = getRnr (token);
             break;
         }
 
-        do { // Begin cleanup block (not a loop)
-            QUrl replyUrl = reply->url ();
-            QString strReplyUrl = replyUrl.toString();
-            if (!strReplyUrl.contains (GOOGLE_ACCOUNTS)) {
-                break;
-            }
-
-            QRegExp rxBody("<body.*>(.*)</body>");
-            rxBody.setMinimal(true);
-            if (!strResponse.contains (rxBody)) {
-                break;
-            }
-
-            QString cap = rxBody.cap (1);
-
-            QDomDocument doc("foreign");
-            doc.setContent (cap);
-
-            QDomElement docElem = doc.documentElement();
-            if (docElem.isNull ()) {
-                break;
-            }
-
-            QString docElemText = docElem.text ();
-#if 0
-            Q_DEBUG(docElemText);
-            Q_DEBUG(docElem.tagName ());
-#endif
-
-            if (docElemText.contains ("The username or password you entered "
-                                      "is incorrect."))
-            {
-                Q_WARN("Found Google's login failure string.");
-                break;
-            }
-
-            bool needsTwoFactor = false;
-            QDomElement twoFactorForm;
-
-            QRegExp rxForm("<form.*>(.*)</form>");
-            rxForm.setMinimal(true);
-            int pos = cap.indexOf (rxForm);
-            while (-1 != pos) {
-                QDomDocument doc1("foreign");
-                QString cap1 = rxForm.cap (0);
-                doc1.setContent (cap1);
-                twoFactorForm = doc1.documentElement();
-                if (twoFactorForm.isNull ()) {
-                    break;
-                }
-                QString formId = twoFactorForm.attribute ("id");
-                if (formId == "verify-form") {
-                    needsTwoFactor = true;
-                    break;
-                }
-
-                pos = cap.indexOf (rxForm, pos + cap1.length ());
-            }
-
-            if (needsTwoFactor) {
-                if (emitLog) {
-                    Q_DEBUG("Two factor AUTH required!");
-                }
-
-                token->inParams["tfaAction"] = twoFactorForm.attribute("action");
-
-                emit twoStepAuthentication(token);
-                foreignUrl = true;
-                break;
-            }
-
-            QDomNodeList aList = docElem.elementsByTagName ("a");
-            if (aList.isEmpty ()) {
-                break;
-            }
-
-            QString newLoc;
-            for (uint i = 0; i < aList.length (); i++) {
-                QDomElement a = aList.at(i).toElement ();
-                if (a.isNull ()) {
-                    continue;
-                }
-
-                newLoc = a.attribute ("href");
-                if (newLoc.isEmpty ()) {
-                    continue;
-                }
-
-                break;
-            }
-
-            if (newLoc.isEmpty ()) {
-                break;
-            }
-
-            Q_DEBUG("Foreign account! Destination: ") << newLoc;
-            foreignUrl = true;
-
-            urlMoved = QUrl(newLoc);
-            success = doGet(urlMoved, token, this,
-                   SLOT(onLogin2(bool,const QByteArray&,QNetworkReply*,void*)));
-            token->outParams["foreign"] = 0;
-        } while (0); // End cleanup block (not a loop)
-
-        if (foreignUrl) {
-            break;
-        }
-
-        // After this we should have completed login. Check for cookie "gvx"
-        foreach (QNetworkCookie cookie, jar->getAllCookies ()) {
-            if (cookie.name() == "gvx") {
-                loggedIn = true;
-                break;
-            }
-        }
-
-        // If "gvx" was found, then we're logged in.
-        if (!loggedIn) {
+        // 2 factor auth is required.
+        hiddenLoginFields.clear ();
+        if (!parseHiddenLoginFields (strResponse, hiddenLoginFields)) {
+            Q_WARN("Failed to parse hidden fields");
             success = false;
             break;
         }
 
-        success = getRnr (token);
+        QString nextAction;
+        QRegExp rxForm("<form.*>(.*)</form>");
+        rxForm.setMinimal(true);
+        int pos = strResponse.indexOf (rxForm);
+        while (-1 != pos) {
+            QString cap = rxForm.cap (0);
+            quint32 len = cap.length ();
+            QRegExp rxAction("action=[\"|'](.*)[\"|']");
+            rxAction.setMinimal (true);
+            if (cap.contains ("verify-form")) {
+                if (cap.contains (rxAction)) {
+                    nextAction = rxAction.cap (1);
+                    break;
+                }
+            }
+
+            pos = strResponse.indexOf (rxForm, pos + len);
+        }
+
+        if (nextAction.isEmpty ()) {
+            Q_WARN("Failed to get two factor auth form");
+            success = false;
+            break;
+        }
+
+        if (emitLog) {
+            Q_DEBUG("Two factor AUTH required!");
+        }
+        token->inParams["tfaAction"] = nextAction;
+        emit twoStepAuthentication(token);
+        success = true;
     } while (0); // End cleanup block (not a loop)
 
     if (!success) {
@@ -881,24 +833,28 @@ GVApi::onTFAAutoPost(bool success, const QByteArray &response,
         }
 
         success = false;
-        QRegExp rx("<form\\s*action\\s*=\\s*\"(.*)\"\\s*method\\s*=\\s*\"POST\"");
-        if ((rx.indexIn (strResponse) == -1) || (rx.numCaptures () != 1)) {
+        QRegExp rx1("<form(.*)>");
+        rx1.setMinimal (true);
+        if ((rx1.indexIn (strResponse) == -1) || (rx1.numCaptures () != 1)) {
             Q_WARN("Failed to login.");
             break;
         }
 
-        QUrl nextUrl(rx.cap(1));
-
-        QVariantMap ret;
-        if (!parseHiddenLoginFields (strResponse, ret)) {
+        QString cap = rx1.cap(1);
+        QRegExp rx2("action\\s*=\\s*\"(.*)\"");
+        rx2.setMinimal (true);
+        if ((rx2.indexIn (cap) == -1) || (rx2.numCaptures () != 1)) {
             Q_WARN("Failed to login.");
             break;
         }
+        cap = rx2.cap (1);
 
-        QStringList keys;
-        keys = ret.keys();
-        foreach (QString key, keys) {
-            hiddenLoginFields[key] = ret[key];
+        QUrl nextUrl = QUrl::fromPercentEncoding (cap.toLatin1 ());
+
+        hiddenLoginFields.clear ();
+        if (!parseHiddenLoginFields (strResponse, hiddenLoginFields)) {
+            Q_WARN("Failed to login.");
+            break;
         }
 
         success = postLogin (nextUrl, token);
@@ -992,6 +948,7 @@ GVApi::onGotRnr(bool success, const QByteArray &response, QNetworkReply *reply,
 
         rnr_se = rx.cap (1);
 
+        token->outParams["rnr_se"] = rnr_se;
         token->status = ATTS_SUCCESS;
         token->emitCompleted ();
         token = NULL;
@@ -1200,24 +1157,36 @@ GVApi::onGetPhones(bool success, const QByteArray &response, QNetworkReply *,
                 }
 
                 if (strPName == "id") {
-                    regNumber.strId = strVal;
+                    regNumber.id = strVal;
                 } else if (strPName == "name") {
-                    regNumber.strName = strVal;
+                    regNumber.name = strVal;
                 } else if (strPName == "phoneNumber") {
-                    regNumber.strNumber = strVal;
+                    regNumber.number = strVal;
                 } else if (strPName == "type") {
                     regNumber.chType = strVal[0].toAscii ();
-                } else if ((strPName == "verified") ||
-                           (strPName == "policyBitmask") ||
+                } else if (strPName == "verified") {
+                    regNumber.verified = (strVal == "true");
+                } else if (strPName == "smsEnabled") {
+                    regNumber.smsEnabled = (strVal == "true");
+                } else if (strPName == "telephonyVerified") {
+                    regNumber.telephonyVerified = (strVal == "true");
+                } else if (strPName == "active") {
+                    regNumber.active = (strVal == "true");
+                } else if (strPName == "inVerification") {
+                    regNumber.inVerification = (strVal == "true");
+                } else if (strPName == "reverifyNeeded") {
+                    regNumber.reverifyNeeded = (strVal == "true");
+                } else if (strPName == "forwardingCountry") {
+                    regNumber.forwardingCountry = strVal;
+                } else if (strPName == "displayUnverifyScheduledDateTime") {
+                    regNumber.displayUnverifyScheduledDateTime = strVal;
+                } else if ((strPName == "policyBitmask") ||
                            (strPName == "dEPRECATEDDisabled") ||
-                           (strPName == "telephonyVerified") ||
-                           (strPName == "smsEnabled") ||
                            (strPName == "incomingAccessNumber") ||
                            (strPName == "voicemailForwardingVerified") ||
                            (strPName == "behaviorOnRedirect") ||
                            (strPName == "carrier") ||
                            (strPName == "customOverrideState") ||
-                           (strPName == "inVerification") ||
                            (strPName == "recentlyProvisionedOrDeprovisioned") ||
                            (strPName == "formattedNumber") ||
                            (strPName == "wd") ||
@@ -1228,7 +1197,6 @@ GVApi::onGetPhones(bool success, const QByteArray &response, QNetworkReply *,
                            (strPName == "weekendAllDay") ||
                            (strPName == "weekendTimes") ||
                            (strPName == "redirectToVoicemail") ||
-                           (strPName == "active") ||
                            (strPName == "enabledForOthers")) {
                 } else {
                     if (emitLog) {
@@ -1239,8 +1207,8 @@ GVApi::onGetPhones(bool success, const QByteArray &response, QNetworkReply *,
             }
 
             if (emitLog) {
-                Q_DEBUG("Name =") << regNumber.strName
-                    << "number =" << regNumber.strNumber
+                Q_DEBUG("Name =") << regNumber.name
+                    << "number =" << regNumber.number
                     << "type ="   << regNumber.chType;
             }
             emit registeredPhone (regNumber);
@@ -1760,9 +1728,8 @@ GVApi::callOut(AsyncTaskToken *token)
         return (true);
     }
 
-    // Ensure that the params  are valid
-    if (!token->inParams.contains ("destination"))
-    {
+    // Ensure that the params are valid
+    if (!token->inParams.contains ("destination")) {
         token->status = ATTS_INVALID_PARAMS;
         token->emitCompleted ();
         return true;
@@ -1774,14 +1741,17 @@ GVApi::callOut(AsyncTaskToken *token)
         return true;
     }
 
+    QString fwdingNum = token->inParams["source"].toString();
     QString dest = token->inParams["destination"].toString();
     QUrl url(GV_HTTPS_M "/x");
     url.addQueryItem("m" , "call");
     url.addQueryItem("n" , dest);
-    url.addQueryItem("f" , "");
-    url.addQueryItem("v" , "7");
+    url.addQueryItem("f" , fwdingNum);
+    url.addQueryItem("v" , "11");
 
-    Q_DEBUG(QString("Call back: dest=%1, using=").arg(dest));
+    if (emitLog) {
+        Q_DEBUG(QString("Call out: dest=%1, using=%2").arg(dest, fwdingNum));
+    }
 
     QByteArray content;
     QList<QNetworkCookie> allCookies = jar->getAllCookies ();
@@ -1995,7 +1965,7 @@ GVApi::sendSms(AsyncTaskToken *token)
     url.addQueryItem("m" , "sms");
     url.addQueryItem("n" , token->inParams["destination"].toString());
     url.addQueryItem("f" , "");
-    url.addQueryItem("v" , "7");
+    url.addQueryItem("v" , "11");
     url.addQueryItem("txt",token->inParams["text"].toString());
 
     return doSendSms (url, token);
@@ -2141,19 +2111,16 @@ GVApi::onVmail(bool success, const QByteArray &response, QNetworkReply *,
         file.close();
 
         token->status = ATTS_SUCCESS;
-        token->emitCompleted ();
-        token = NULL;
 
         success = true;
     } while (0); // End cleanup block (not a loop)
 
-    if (!success) {
-        if (token) {
-            if (token->status == ATTS_SUCCESS) {
-                token->status = ATTS_FAILURE;
-            }
-            token->emitCompleted ();
+    if (NULL != token) {
+        if (!success) {
+            token->status = ATTS_FAILURE;
         }
+        token->emitCompleted ();
+        token = NULL;
     }
 }//GVApi::onVmail
 
@@ -2439,8 +2406,36 @@ GVApi::onCheckRecentInbox(bool success, const QByteArray &response,
             serverLatest = QDateTime::fromMSecsSinceEpoch (0);
         }
 
+        quint32 totalSize;
+        totalSize = scriptEngine.evaluate("obj[\"totalSize\"]").toInt32 ();
+        if (scriptEngine.hasUncaughtException ()) {
+            Q_WARN("Uncaught exception executing script :")
+                << scriptEngine.uncaughtException().toString()
+                << "JSON =" << xmlHandler.strJson;
+            break;
+        }
+
+#if 0
+        QString fName;
+        if (!token->outParams.contains ("serverLatest")) {
+            fName = "updateAll.html";
+        } else {
+            fName = "updateTrash.html";
+        }
+
+        QFile fTemp(fName);
+        fTemp.open (QFile::ReadWrite);
+        fTemp.write (response);
+        fTemp.close ();
+#endif
+
+        // Now that I've got the latest from inbox/all, look for it in trash.
+        // The completion callback for trash is this (same) function.
+        // To make sure that I don't fall into an infinite loop, look for trash
+        // only if the outParams doesn't have the "serverLatest" field.
         if (!token->outParams.contains ("serverLatest")) {
             token->outParams["serverLatest"] = serverLatest;
+            token->outParams["allCount"] = totalSize;
 
             success = doGet(GV_HTTPS "/b/0/inbox/recent/trash", token, this,
                             SLOT(onCheckRecentInbox(bool,const QByteArray&,QNetworkReply*,void*)));
@@ -2456,6 +2451,9 @@ GVApi::onCheckRecentInbox(bool success, const QByteArray &response,
             break;
         }
 
+        // Reaching here means that this is the trash results path
+        token->outParams["trashCount"] = totalSize;
+
         QDateTime allEntryTime = token->outParams["serverLatest"].toDateTime();
         if (serverLatest > allEntryTime) {
             token->outParams["serverLatest"] = serverLatest;
@@ -2481,6 +2479,10 @@ GVApi::onCheckRecentInbox(bool success, const QByteArray &response,
 void
 GVApi::resetNwMgr()
 {
+    if (emitLog) {
+        Q_DEBUG("Changing network manager");
+    }
+
     if (NULL != nwMgr) {
         nwMgr->deleteLater ();
         nwMgr = NULL;
