@@ -1,6 +1,6 @@
 /*
 qgvdial is a cross platform Google Voice Dialer
-Copyright (C) 2009-2012  Yuvraaj Kelkar
+Copyright (C) 2009-2013  Yuvraaj Kelkar
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
@@ -234,7 +234,7 @@ GVInbox::oneInboxEntry (const GVInboxEntry &hevent)
 
         modelInbox->insertEntry (hevent);
     } else {
-        Q_DEBUG(QString("Delete entry with ID %1").arg (hevent.id));
+        //Q_DEBUG(QString("Delete entry with ID %1").arg (hevent.id));
         passedWaterLevel = true;
 
         modelInbox->deleteEntry (hevent);
