@@ -1,6 +1,6 @@
 /*
 qgvdial is a cross platform Google Voice Dialer
-Copyright (C) 2009-2012  Yuvraaj Kelkar
+Copyright (C) 2009-2013  Yuvraaj Kelkar
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
@@ -161,11 +161,20 @@ MainWindow::dialNow (const QString &strTarget)
         gvApiProgressString = "Call progress";
         if (bDialout) {
             ctx->ci = ci;
+            QString assocNum = ci->getAssociatedNumber ();
+            
+            if (assocNum.isEmpty()) {
+                setStatus ("Dial out needs source number.");
+                Q_WARN ("Dial out needs source number.");
+                break;
+            }
 
-            token->inParams["source"] = ci->selfNumber ();
+            Q_DEBUG(assocNum);
+
+            token->inParams["source"] = assocNum;
             success = gvApi.callOut (token);
         } else {
-            token->inParams["source"] = gvRegNumber.strNumber;
+            token->inParams["source"] = gvRegNumber.number;
             token->inParams["sourceType"] = QString(gvRegNumber.chType);
             success = gvApi.callBack (token);
         }
@@ -425,8 +434,8 @@ MainWindow::getDialSettings (bool                 &bDialout   ,
         }
 
         gvRegNumber.chType = data.chType;
-        gvRegNumber.strName = data.strName;
-        gvRegNumber.strNumber = data.strDesc;
+        gvRegNumber.name = data.strName;
+        gvRegNumber.number = data.strDesc;
         bDialout = (data.type == RNT_Callout);
         if (bDialout) {
             initiator = (CalloutInitiator *) data.pCtx;
