@@ -1,6 +1,6 @@
 /*
 qgvdial is a cross platform Google Voice Dialer
-Copyright (C) 2009-2012  Yuvraaj Kelkar
+Copyright (C) 2009-2013  Yuvraaj Kelkar
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
@@ -21,7 +21,6 @@ Contact: yuvraaj@gmail.com
 
 #include "MainWindow.h"
 
-
 /** Invoked to begin the login process.
  * We already have the username and password, so just start the login to the GV
  * website. The async completion routine is loginCompleted.
@@ -166,40 +165,7 @@ MainWindow::loginCompleted (AsyncTaskToken *token)
         return;
     }
 
-    if (token->status != ATTS_SUCCESS) {
-        logoutCompleted (NULL);
-
-        OsDependent &osd = Singletons::getRef().getOSD ();
-        osd.setLongWork (this, false);
-
-        QString strErr = token->errorString;
-
-        if (token->status == ATTS_NW_ERROR) {
-            loginStatus = LS_NwError;
-            if (strErr.isEmpty ()) {
-                strErr = "Network error";
-            }
-        } else {
-            dbMain.clearUser ();
-            dbMain.clearPass ();
-            dbMain.clearContactsPass ();
-            dbMain.setTFAFlag (false);
-            QTimer::singleShot (500, this, SLOT(onRecreateCookieJar()));
-        }
-
-        if (token->status == ATTS_LOGIN_FAIL_SHOWURL) {
-            QUrl url = token->outParams["nextUrl"].toUrl ();
-            QDesktopServices::openUrl (url);
-        }
-
-        if (strErr.isEmpty ()) {
-            strErr = "User login failed";
-            setStatus ("User login failed", 30*1000);
-        }
-        this->showMsgBox (strErr);
-
-        Q_WARN(QString("User login failed. Error string: %1").arg(strErr));
-    } else {
+    if (token->status == ATTS_SUCCESS) {
         setStatus ("User logged in");
         Q_DEBUG ("User logged in");
 
@@ -207,7 +173,10 @@ MainWindow::loginCompleted (AsyncTaskToken *token)
         dbMain.getUserPass (strOldUser, strOldPass);
         if (strOldUser != strUser) {
             // Cleanup cache
-            dbMain.blowAwayCache ();
+            if (!dbMain.blowAwayCache ()) {
+                requestQuit ();
+                return;
+            }
             dbMain.ensureCache ();
         }
 
@@ -234,6 +203,12 @@ MainWindow::loginCompleted (AsyncTaskToken *token)
             initContacts (contactsPass);
         }
 
+        if (token->outParams["rnr_se"].toString().isEmpty()) {
+            Q_WARN("GV may not work correctly: rnr_se is empty!");
+            showMsgBox ("GV account configuration may not be complete. "
+                        "Everything may not work as expected.");
+        }
+
         // Prepare the inbox widget for usage
         initInbox ();
 
@@ -268,6 +243,39 @@ MainWindow::loginCompleted (AsyncTaskToken *token)
 
         // Fill up the pin settings
         refreshPinSettings ();
+    } else {
+        logoutCompleted (NULL);
+
+        OsDependent &osd = Singletons::getRef().getOSD ();
+        osd.setLongWork (this, false);
+
+        QString strErr = token->errorString;
+
+        if (token->status == ATTS_NW_ERROR) {
+            loginStatus = LS_NwError;
+            if (strErr.isEmpty ()) {
+                strErr = "Network error";
+            }
+        } else {
+            dbMain.clearUser ();
+            dbMain.clearPass ();
+            dbMain.clearContactsPass ();
+            dbMain.setTFAFlag (false);
+            QTimer::singleShot (500, this, SLOT(onRecreateCookieJar()));
+        }
+
+        if (token->status == ATTS_LOGIN_FAIL_SHOWURL) {
+            QUrl url = token->outParams["nextUrl"].toUrl ();
+            QDesktopServices::openUrl (url);
+        }
+
+        if (strErr.isEmpty ()) {
+            strErr = "User login failed";
+            setStatus ("User login failed", 30*1000);
+        }
+        this->showMsgBox (strErr);
+
+        Q_WARN(QString("User login failed. Error string: %1").arg(strErr));
     }
 
     if (token) {
