@@ -1,6 +1,6 @@
 /*
 qgvdial is a cross platform Google Voice Dialer
-Copyright (C) 2009-2012  Yuvraaj Kelkar
+Copyright (C) 2009-2013  Yuvraaj Kelkar
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
@@ -31,6 +31,8 @@ MainWindow::MainWindow (QWidget *parent)
 , gvApi (true, this)
 , icoQgv (":/qgv.png")
 , pSystray (NULL)
+, m_dialoutSelectionDialog(NULL)
+, m_registeredPhonesModel(NULL)
 , oContacts (NULL)
 , oInbox (NULL)
 , bBeginPlayAfterLoad (false)
@@ -267,6 +269,22 @@ MainWindow::init ()
                   &osd, SIGNAL(phoneChanges(const QStringList &,int)));
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
+    rv = connect (&osd, SIGNAL(sigOpenInbox()),
+                  this, SLOT(onSigOpenInbox()));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+    rv = connect (&osd, SIGNAL(sigOpenContacts()),
+                  this, SLOT(onSigOpenContacts()));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+    rv = connect (&osd, SIGNAL(sigRefresh()),
+                  this, SLOT(onRefresh()));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+    rv = connect (&osd, SIGNAL(sigQuit()),
+                  this, SLOT(on_actionE_xit_triggered()));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
 
     // Set up cookies
     QList<QNetworkCookie> cookies;
@@ -280,8 +298,8 @@ MainWindow::init ()
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
     rv =
-    connect(&gvApi, SIGNAL (registeredPhone    (const GVRegisteredNumber &)),
-             this , SLOT   (gotRegisteredPhone (const GVRegisteredNumber &)));
+    connect(&gvApi, SIGNAL(registeredPhone(const GVRegisteredNumber&)),
+             this , SLOT(gotRegisteredPhone(const GVRegisteredNumber&)));
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
 
@@ -409,13 +427,7 @@ MainWindow::init ()
     clearSmsDestinations ();
 
     // Save the temp store location for contact photos
-    QString strTempStore = osd.getAppDirectory();
-    QDir dirApp(strTempStore);
-    strTempStore += QDir::separator() + tr("temp");
-    if (!QFileInfo(strTempStore).exists ()) {
-        dirApp.mkdir ("temp");
-    }
-    oContacts->setTempStore(strTempStore);
+    oContacts->setTempStore(dbMain.getTempDirectory ());
 
 #if MOSQUITTO_CAPABLE
     // Connect the signals from the Mosquitto thread
@@ -439,10 +451,15 @@ MainWindow::init ()
 
     // When there is a real change in the NW configuration, reset the nw access
     // manager on the GvAPI class object
-    rv = connect(&Singletons::getRef().getNwInfo(), SIGNAL(realChange()),
+    NwInfo &nwInfo = Singletons::getRef().getNwInfo();
+    rv = connect(&nwInfo, SIGNAL(realChange()),
                  &gvApi, SLOT(resetNwMgr()));
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
+    rv = connect(&nwInfo, SIGNAL(realChange()),
+                 this, SLOT(refreshPeriodSettings()));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
 
     // If the cache has the username and password, begin login
     if (dbMain.getUserPass (strUser, strPass)) {
@@ -499,8 +516,8 @@ MainWindow::initQML ()
     this->setPassword ("hunter2 :p");
 
     // The root object changes when we reload the source. Pick it up again.
-    QObject *gObj = this->getQMLObject ("MainPage");
-    if (NULL == gObj) {
+    QObject *obj = this->getQMLObject ("MainPage");
+    if (NULL == obj) {
         Q_WARN("Could not get to MainPage");
         requestQuit ();
         return;
@@ -508,105 +525,105 @@ MainWindow::initQML ()
 
     bool rv;
     // Connect all signals to slots in this class.
-    rv = connect (gObj, SIGNAL(sigCall(QString)),
+    rv = connect (obj, SIGNAL(sigCall(QString)),
                   this, SLOT  (dialNow(QString)));
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
     rv = connect (
-        gObj, SIGNAL (sigText(const QString&,const QString&)),
+        obj, SIGNAL (sigText(const QString&,const QString&)),
         this, SLOT   (onSigText(const QString&,const QString&)));
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
-    rv = connect (gObj, SIGNAL(sigSelChanged(int)),
-                  this, SLOT(onRegPhoneSelectionChange(int)));
-    Q_ASSERT(rv);
-    if (!rv) { exit(1); }
-    rv = connect (gObj, SIGNAL(sigHide ()),
+    rv = connect (obj, SIGNAL(sigHide ()),
                   this, SLOT(onSigHide ()));
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
-    rv = connect (gObj, SIGNAL(sigQuit ()),
+    rv = connect (obj, SIGNAL(sigQuit ()),
                   this, SLOT(on_actionE_xit_triggered ()));
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
     rv = connect (
-        gObj     , SIGNAL(sigSearchContacts(const QString &)),
+        obj     , SIGNAL(sigSearchContacts(const QString &)),
         oContacts, SLOT(onSearchQueryChanged(const QString &)));
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
 
-    rv = connect (gObj, SIGNAL(sigRefreshContacts()),
+    rv = connect (obj, SIGNAL(sigRefreshContacts()),
                   oContacts, SLOT(refreshContacts()));
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
-    rv = connect (gObj, SIGNAL(sigRefreshAllContacts()),
+    rv = connect (obj, SIGNAL(sigRefreshAllContacts()),
                   oContacts, SLOT(refreshAllContacts()));
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
 
-    rv = connect (gObj, SIGNAL(sigHaptic()),
+    rv = connect (obj, SIGNAL(sigHaptic()),
                   this, SLOT(onBtnClickFroHapticFeedback()));
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
 
-    gObj = getQMLObject ("RegisteredPhonesView");
-    if (NULL == gObj) {
+    obj = getQMLObject ("RegisteredPhonesView");
+    if (NULL == obj) {
         Q_WARN("Could not get to RegisteredPhonesView");
         requestQuit ();
         return;
     }
-    rv = connect (gObj, SIGNAL (sigSelChanged (int)),
-                  this, SLOT   (onRegPhoneSelectionChange (int)));
+    rv = connect (obj, SIGNAL(sigSelChanged(int)),
+                  this, SLOT(onRegPhoneSelectionChange(int)));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+    rv = connect (obj, SIGNAL(sigSelOptions(QString)),
+                  this, SLOT(onRegPhoneSelectionOptions(QString)));
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
 
-    gObj = getQMLObject ("MsgBox");
-    if (NULL == gObj) {
+    obj = getQMLObject ("MsgBox");
+    if (NULL == obj) {
         Q_WARN("Could not get to MsgBox");
         requestQuit ();
         return;
     }
-    rv = connect (gObj, SIGNAL(sigOk()), this, SLOT(onSigMsgBoxOk()));
+    rv = connect (obj, SIGNAL(sigOk()), this, SLOT(onSigMsgBoxOk()));
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
-    rv = connect (gObj, SIGNAL(sigCancel()), this, SLOT(onSigMsgBoxCancel()));
+    rv = connect (obj, SIGNAL(sigCancel()), this, SLOT(onSigMsgBoxCancel()));
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
 
-    gObj = getQMLObject ("InboxPage");
-    if (NULL == gObj) {
+    obj = getQMLObject ("InboxPage");
+    if (NULL == obj) {
         Q_WARN("Could not get to InboxPage");
         requestQuit ();
         return;
     }
-    rv = connect (gObj  , SIGNAL(sigInboxSelect(QString)),
+    rv = connect (obj  , SIGNAL(sigInboxSelect(QString)),
                   oInbox, SLOT(onInboxSelected(const QString&)));
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
-    rv = connect (gObj, SIGNAL(sigVoicemail(QString)),
+    rv = connect (obj, SIGNAL(sigVoicemail(QString)),
                   this, SLOT(retrieveVoicemail(const QString&)));
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
-    rv = connect (gObj, SIGNAL(sigVmailPlayback(int)),
+    rv = connect (obj, SIGNAL(sigVmailPlayback(int)),
                   this, SLOT(onSigVmailPlayback(int)));
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
-    rv = connect (gObj  , SIGNAL(sigMarkAsRead(QString)),
+    rv = connect (obj  , SIGNAL(sigMarkAsRead(QString)),
                   oInbox, SLOT(onSigMarkAsRead(const QString &)));
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
-    rv = connect (gObj, SIGNAL(sigRefreshInbox()),
+    rv = connect (obj, SIGNAL(sigRefreshInbox()),
                   oInbox, SLOT(refresh()));
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
-    rv = connect (gObj, SIGNAL(sigRefreshAllInbox()),
+    rv = connect (obj, SIGNAL(sigRefreshAllInbox()),
                   oInbox, SLOT(refreshFullInbox()));
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
-    rv = connect(gObj, SIGNAL(sigCloseVmail()), this, SLOT(onSigCloseVmail()));
+    rv = connect(obj, SIGNAL(sigCloseVmail()), this, SLOT(onSigCloseVmail()));
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
-    rv = connect(gObj, SIGNAL(sigDeleteInboxEntry(const QString &)),
+    rv = connect(obj, SIGNAL(sigDeleteInboxEntry(const QString &)),
                  this, SLOT(onSigDeleteInboxEntry(const QString &)));
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
@@ -621,6 +638,41 @@ MainWindow::initQML ()
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
 
+    IPhoneIntegration &phoneIntegration = Singletons::getRef().getPhoneIntegration();
+    rv = connect(&phoneIntegration, SIGNAL(enableChanged(bool)),
+                 this, SLOT(onPhoneIntegrationChanged(bool)));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+
+    obj = getQMLObject ("PhoneIntegrationView");
+    if (NULL != obj) {
+        // Only if the phone integration exists will we get this page
+        rv = connect(obj, SIGNAL(sigIntegrateChanged(bool)),
+                     &phoneIntegration, SLOT(phoneIntegrationChanged(bool)));
+        Q_ASSERT(rv);
+        if (!rv) { exit(1); }
+    }
+
+    obj = getQMLObject ("DialoutSelectionDialog");
+    if (NULL == obj) {
+        Q_WARN("Could not get to DialoutSelectionDialog");
+        requestQuit ();
+        return;
+    }
+    m_dialoutSelectionDialog = obj;
+    rv = connect(obj, SIGNAL(sigSelected(QString)),
+                 this, SLOT(onDialoutOptionSelected(QString)));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+
+    obj = getQMLObject ("RegisteredPhonesModel");
+    if (NULL == obj) {
+        Q_WARN("Could not get to RegisteredPhonesModel");
+        requestQuit ();
+        return;
+    }
+    m_registeredPhonesModel = obj;
+
 #if DESKTOP_OS
     Qt::WindowFlags flags = this->windowFlags ();
     flags |= Qt::CustomizeWindowHint;
@@ -628,8 +680,8 @@ MainWindow::initQML ()
     this->setWindowFlags (flags);
     this->setFixedSize(this->size());
 
-    gObj = getQMLObject ("CloseButton");
-    gObj->setProperty ("visible", (bool)false);
+    obj = getQMLObject ("CloseButton");
+    obj->setProperty ("visible", (bool)false);
 #endif
 
 }//MainWindow::initQML
@@ -950,6 +1002,42 @@ MainWindow::onRegPhoneSelectionChange (int index)
     emit regPhoneChange(phones, index);
 }//MainWindow::onRegPhoneSelectionChange
 
+void
+MainWindow::onRegPhoneSelectionOptions (QString id)
+{
+    Q_DEBUG(QString("Options for %1").arg (id));
+    // Get the current phone number (if set) for the dial out method.
+    // Open the dialog box, and save the id so that it can be used in
+    // MainWindow::onDialoutOptionSelected
+    m_dialoutSelectionDialog->setProperty ("opacity", 1);
+    m_dialoutSelectionId = id;
+}//MainWindow::onRegPhoneSelectionOptions
+
+void
+MainWindow::onDialoutOptionSelected(QString phoneNumber)
+{
+    Q_DEBUG(QString("User selected number %1 for option %2")
+            .arg(phoneNumber).arg (m_dialoutSelectionId));
+    m_dialoutSelectionDialog->setProperty ("opacity", 0);
+
+    bool found = false;
+    CallInitiatorFactory& cif = Singletons::getRef().getCIFactory ();
+    foreach (CalloutInitiator *ci, cif.getInitiators()) {
+        if (ci->id () == m_dialoutSelectionId) {
+            ci->setAssociatedNumber(phoneNumber);
+
+            CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
+            dbMain.setCIAssociation (ci->id(), phoneNumber);
+            Q_DEBUG(QString("CI %1 = %2 saved").arg(ci->id(), phoneNumber));
+            found = true;
+            break;
+        }
+    }
+    if (!found) {
+        Q_WARN(QString("CI %1 not found!!").arg(m_dialoutSelectionId));
+    }
+}//MainWindow::onDialoutOptionSelected
+
 void
 MainWindow::onRefresh ()
 {
@@ -1136,6 +1224,12 @@ MainWindow::onSigPinSettingChanges(bool bEnable, const QString &pin)
 
     CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
     dbMain.setGvPin (bEnable, strPin);
+
+    if (bEnable) {
+        strGvPin = strPin;
+    } else {
+        strGvPin = "0000";
+    }
 }//MainWindow::onSigPinSettingChanges
 
 void
@@ -1169,7 +1263,7 @@ MainWindow::refreshPinSettings()
 }//MainWindow::refreshPinSettings
 
 void
-MainWindow::showMsgBox (const QString &strMessage, bool inputBox)
+MainWindow::showMsgBox (const QString &strMessage, bool inputBox /*= false*/)
 {
     QObject *obj = getQMLObject ("MsgBox");
     if (NULL == obj) {
@@ -1182,18 +1276,6 @@ MainWindow::showMsgBox (const QString &strMessage, bool inputBox)
     obj->setProperty ("opacity", QVariant(1.0));
 }//MainWindow::showMsgBox
 
-void
-MainWindow::showMsgBox (const QString &strMessage)
-{
-    showMsgBox (strMessage, false);
-}//MainWindow::showMsgBox
-
-void
-MainWindow::showInputBox (const QString &strMessage)
-{
-    showMsgBox (strMessage, true);
-}//MainWindow::showInputBox
-
 void
 MainWindow::onSigMsgBoxDone (bool ok /* = true*/)
 {
@@ -1223,9 +1305,6 @@ MainWindow::onSigMsgBoxCancel()
 void
 MainWindow::onCallInitiatorsChange (bool bSave)
 {
-    QObject *model = getQMLObject ("RegisteredPhonesModel");
-    Q_ASSERT(model);
-
     // Set the correct callback
     CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
     QString strCallback;
@@ -1235,26 +1314,33 @@ MainWindow::onCallInitiatorsChange (bool bSave)
     QScriptEngine scriptEngine;
     bool isChecked = false;
 
-    QString strCiName;
+    QString strCiName, strCiNum;
 
     // Clear out all entries in the model...
-    QMetaObject::invokeMethod (model, "clear");
+    QMetaObject::invokeMethod (m_registeredPhonesModel, "clear");
+    QMetaObject::invokeMethod (m_dialoutSelectionDialog, "clearModel");
     modelRegNumber->clear ();
 
     for (int i = 0; i < arrNumbers.size (); i++) {
-        strCiName = "Dial back: " + arrNumbers[i].strName;
+        strCiName = "Dial back: " + arrNumbers[i].name;
         modelRegNumber->insertRow (strCiName,
-                                   arrNumbers[i].strNumber,
+                                   arrNumbers[i].number,
                                    arrNumbers[i].chType);
 
         oneEntry.clear ();
         oneEntry["entryText"] = strCiName;
-        oneEntry["entryNumber"] = arrNumbers[i].strNumber;
+        oneEntry["entryNumber"] = arrNumbers[i].number;
         oneEntry["entryType"] = arrNumbers[i].chType;
         oneEntry["isChecked"] = isChecked;
+        oneEntry["entryID"] = "undefined";
 
-        QMetaObject::invokeMethod (model, "append",
+        QMetaObject::invokeMethod (m_registeredPhonesModel, "append",
             Q_ARG(QScriptValue, scriptEngine.toScriptValue(oneEntry)));
+
+        if (arrNumbers[i].chType != '9') {
+            QMetaObject::invokeMethod (m_dialoutSelectionDialog, "addEntry",
+                                       Q_ARG(QVariant, arrNumbers[i].number));
+        }
     }
 
     // Store the callouts in the same widget as the callbacks
@@ -1269,9 +1355,18 @@ MainWindow::onCallInitiatorsChange (bool bSave)
             oneEntry["entryNumber"] = ci->selfNumber ();
             oneEntry["entryType"] = 'O';
             oneEntry["isChecked"] = isChecked;
+            oneEntry["entryID"] = ci->id ();
 
-            QMetaObject::invokeMethod (model, "append",
+            QMetaObject::invokeMethod (m_registeredPhonesModel, "append",
                 Q_ARG(QScriptValue, scriptEngine.toScriptValue(oneEntry)));
+
+            if (dbMain.getCIAssociation (ci->id (), strCiNum)) {
+                ci->setAssociatedNumber (strCiNum);
+                Q_DEBUG(QString("CI %1 found number %2")
+                        .arg(ci->id(), strCiNum));
+            } else {
+                Q_DEBUG(QString("CI %1 found no number").arg(ci->id()));
+            }
         }
     }
 
@@ -1603,3 +1698,40 @@ MainWindow::onPeriodicInboxRefresh()
 
     inboxTimer.start (inboxPeriod);
 }//MainWindow::onPeriodicInboxRefresh
+
+void
+MainWindow::onPhoneIntegrationChanged(bool enable)
+{
+    QObject *obj = getQMLObject ("PhoneIntegrationView");
+    if (NULL == obj) {
+        return;
+    }
+
+    obj->setProperty("enableIntegrate", enable);
+}//MainWindow::onPhoneIntegrationChanged
+
+void
+MainWindow::onSigOpenInbox()
+{
+    QObject *obj = getQMLObject ("TabbedUI");
+    if (NULL == obj) {
+        Q_WARN("Failed to get a handle to the TabbedUI");
+        return;
+    }
+
+    int index = 2;
+    QMetaObject::invokeMethod (obj, "tabClicked", Q_ARG(QVariant, index));
+}//MainWindow::onSigOpenInbox
+
+void
+MainWindow::onSigOpenContacts()
+{
+    QObject *obj = getQMLObject ("TabbedUI");
+    if (NULL == obj) {
+        Q_WARN("Failed to get a handle to the TabbedUI");
+        return;
+    }
+
+    int index = 1;
+    QMetaObject::invokeMethod (obj, "tabClicked", Q_ARG(QVariant, index));
+}//MainWindow::onSigOpenContacts
