@@ -1,6 +1,6 @@
 /*
 qgvdial is a cross platform Google Voice Dialer
-Copyright (C) 2009-2012  Yuvraaj Kelkar
+Copyright (C) 2009-2013  Yuvraaj Kelkar
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
@@ -146,9 +146,19 @@ private slots:
                                    Phonon::State oldState);
     //! Invoked when the QML sends us a vmail play/pause/stop signal
     void onSigVmailPlayback (int newstate);
+    void ensureVmailPlaying();
 
     //! Invoked by QML when the user selects a new phone method
     void onRegPhoneSelectionChange (int index);
+    //! Invoked by QML when the user wanted to set options on the phone
+    void onRegPhoneSelectionOptions (QString id);
+    //! Invoked when the user clicks on a phone number from the selection dlg
+    void onDialoutOptionSelected (QString phoneNumber);
+
+    //! Invoked when the user wishes to open the inbox page
+    void onSigOpenInbox();
+    //! Invoked when the user wishes to open the contacts page
+    void onSigOpenContacts();
 
     //! Invoked when user invokes refresh
     void onRefresh ();
@@ -233,7 +243,7 @@ private slots:
     void onSigDeleteInboxEntry(const QString &id);
     void onUserAllowedDelete(bool ok);
 
-    // Signal for periodic refresh settings changes
+    //! Signal for periodic refresh settings changes
     void
     onSigRefreshChanges(bool bRefreshEnable, const QString &contactsPeriod,
                         const QString &inboxPeriod, bool bMqEnable,
@@ -244,6 +254,9 @@ private slots:
     void onPeriodicContactsRefresh();
     void onPeriodicInboxRefresh();
 
+    //! When the phone integration changes, this slot is fired
+    void onPhoneIntegrationChanged(bool enable);
+
 private:
     void initLogging ();
 
@@ -285,9 +298,9 @@ private:
     //! Request quit in the app
     void requestQuit();
 
-    void showMsgBox (const QString &strMessage, bool inputBox);
-    void showMsgBox (const QString &strMessage);
-    void showInputBox (const QString &strMessage);
+    void showMsgBox (const QString &strMessage, bool inputBox = false);
+    inline void showInputBox(const QString &msg) { showMsgBox(msg, true); }
+
     void onSigMsgBoxDone(bool ok = true);
 
 private:
@@ -296,6 +309,10 @@ private:
     // Tray, icons, widgets
     QIcon           icoQgv;
     QSystemTrayIcon *pSystray;
+
+    QObject         *m_dialoutSelectionDialog;
+    QObject         *m_registeredPhonesModel;
+
     //! GV Contacts object
     GVContactsTable *oContacts;
     //! GV Inbox object
@@ -386,6 +403,11 @@ private:
     FuzzyTimer      contactsTimer;
     //! Inbox refresh fuzzy timer
     FuzzyTimer      inboxTimer;
+
+    //! When the user wants to choose a number for a dialout option, the id
+    //! of the CI needs to be saved here because the dialog box for the number
+    //! is asynchronous
+    QString         m_dialoutSelectionId;
 };
 
 #endif // MAINWINDOW_H
