@@ -1,6 +1,6 @@
 /*
 qgvdial is a cross platform Google Voice Dialer
-Copyright (C) 2009-2012  Yuvraaj Kelkar
+Copyright (C) 2009-2013  Yuvraaj Kelkar
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
@@ -21,6 +21,10 @@ Contact: yuvraaj@gmail.com
 
 #include "OsDependent.h"
 
+#if defined(MEEGO_HARMATTAN)
+#include <MRemoteAction>
+#endif
+
 OsDependent::OsDependent(QObject *parent)
 : QObject(parent)
 , bDBusObjectRegistered(false)
@@ -28,6 +32,7 @@ OsDependent::OsDependent(QObject *parent)
 , dbusCallApi(NULL)
 , dbusTextApi(NULL)
 , dbusSettingsApi(NULL)
+, dbusUiApi(NULL)
 #endif
 {
 #if SYSTEMDISPLAYINFO
@@ -72,6 +77,20 @@ OsDependent::init ()
     }
 #endif
 
+#if defined(MEEGO_HARMATTAN)
+    {
+    MRemoteAction action("org.QGVDial.APIServer",
+                         "/org/QGVDial/UIServer",
+                         "org.QGVDial.UIServer",
+                         "Refresh");
+    QDBusInterface interface("com.nokia.home.EventFeed",
+                             "/eventfeed",
+                             "com.nokia.home.EventFeed",
+                             QDBusConnection::sessionBus());
+    interface.call(QDBus::NoBlock, "addRefreshAction", action.toString());
+    }
+#endif
+
     Q_ASSERT(rv);
 }//OsDependent::init
 
@@ -221,6 +240,43 @@ OsDependent::initApiServer()
             rv = false;
         }
 
+        if (NULL == dbusUiApi) {
+            dbusUiApi = new QGVDBusUiApi(this);
+            if (NULL == dbusUiApi) {
+                Q_WARN("Couldn't allocate UI api");
+                break;
+            }
+            if (!dbusUiApi->registerObject ()) {
+                Q_WARN("Failed to register UI api");
+                break;
+            }
+            rv = connect(dbusUiApi, SIGNAL(sigOpenInbox()),
+                         this, SIGNAL(sigOpenInbox()));
+            if (!rv) {
+                Q_WARN("Failed to connect open inbox signal");
+                break;
+            }
+            rv = connect(dbusUiApi, SIGNAL(sigOpenContacts()),
+                         this, SIGNAL(sigOpenContacts()));
+            if (!rv) {
+                Q_WARN("Failed to connect open contacts signal");
+                break;
+            }
+            rv = connect(dbusUiApi, SIGNAL(sigRefresh()),
+                         this, SIGNAL(sigRefresh()));
+            if (!rv) {
+                Q_WARN("Failed to connect refresh signal");
+                break;
+            }
+            rv = connect(dbusUiApi, SIGNAL(sigQuit()),
+                         this, SIGNAL(sigQuit()));
+            if (!rv) {
+                Q_WARN("Failed to connect quit signal");
+                break;
+            }
+            rv = false;
+        }
+
         rv = true;
     } while(0);
 
@@ -237,6 +293,10 @@ OsDependent::initApiServer()
             delete dbusSettingsApi;
             dbusSettingsApi = NULL;
         }
+        if (NULL != dbusUiApi) {
+            delete dbusUiApi;
+            dbusUiApi = NULL;
+        }
     }
 #endif
 }//OsDependent::initApiServer
@@ -618,6 +678,21 @@ OsDependent::onBtnClickFroHapticFeedback()
 #endif
 }//OsDependent::onBtnClickFroHapticFeedback
 
+IPhoneIntegration *
+OsDependent::createPhoneIntegreationObj(QObject *parent)
+{
+    IPhoneIntegration *rv = NULL;
+#if TELEPATHY_CAPABLE
+    rv = new TpPhoneIntegration(parent);
+#endif
+
+    if (NULL == rv) {
+        // Default object does absolutely nothing
+        rv = new IPhoneIntegration(parent);
+    }
+    return rv;
+}//OsDependent::createPhoneIntegreationObj
+
 #ifdef QT_NO_SYSTEMTRAYICON
 QSystemTrayIcon::QSystemTrayIcon(QWidget *parent /*= 0*/)
 : QWidget (parent)
