@@ -1,6 +1,6 @@
 /*
 qgvdial is a cross platform Google Voice Dialer
-Copyright (C) 2009-2012  Yuvraaj Kelkar
+Copyright (C) 2009-2013  Yuvraaj Kelkar
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
@@ -46,6 +46,7 @@ QTM_USE_NAMESPACE
 
 #if TELEPATHY_CAPABLE
 #include "DBusApi.h"
+#include "TpAccountUtility.h"
 #endif
 
 // For some reason the symbian MOC doesn't like it if I don't include QObject
@@ -93,6 +94,8 @@ public:
 
     void onBtnClickFroHapticFeedback();
 
+    IPhoneIntegration *createPhoneIntegreationObj(QObject *parent);
+
 signals:
     void orientationChanged (OsIndependentOrientation o);
 
@@ -106,6 +109,12 @@ signals:
 
     // Signals from mainwindow -> dial, text and settings servers
     void phoneChanges(const QStringList &phones, int index);
+
+    // Signals from the UI server
+    void sigOpenInbox();
+    void sigOpenContacts();
+    void sigRefresh();
+    void sigQuit();
 ////////////////////////////////////////////////////////////////////////////////
 
 private:
@@ -133,6 +142,7 @@ private:
     QGVDBusCallApi     *dbusCallApi;
     QGVDBusTextApi     *dbusTextApi;
     QGVDBusSettingsApi *dbusSettingsApi;
+    QGVDBusUiApi       *dbusUiApi;
 #endif
 
     friend class Singletons;
