@@ -1,6 +1,6 @@
 /*
 qgvdial is a cross platform Google Voice Dialer
-Copyright (C) 2009-2012  Yuvraaj Kelkar
+Copyright (C) 2009-2013  Yuvraaj Kelkar
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
@@ -31,8 +31,6 @@ Contact: yuvraaj@gmail.com
 #include <QtXml>
 #include <QtScript>
 
-#include "NwReqTracker.h"
-
 #define APPLICATION_NAME "qgvdial"
 
 #define UA_N900    "Mozilla/5.0 (X11; U; Linux armv7l; en-GB; rv:1.9.2a1pre) Gecko/20090928 Firefox/3.5 Maemo Browser 1.4.1.21 RX-51 N900"
@@ -41,7 +39,7 @@ Contact: yuvraaj@gmail.com
 #define UA_IPOD    "Mozilla/5.0 (iPod; U; CPU iPhone OS 4_3_3 like Mac OS X; ja-jp) AppleWebKit/533.17.9 (KHTML, like Gecko) Version/5.0.2 Mobile/8J2 Safari/6533.18.5"
 #define UA_DESKTOP "Mozilla/5.0 (X11; Linux x86_64; rv:5.0) Gecko/20100101 Firefox/5.0"
 
-#define GV_URL          "http://www.google.com/voice"
+#define GV_HTTP         "http://www.google.com/voice"
 #define GV_HTTPS        "https://www.google.com/voice"
 #define GV_HTTPS_M      "https://www.google.com/voice/m"
 
@@ -58,21 +56,37 @@ Contact: yuvraaj@gmail.com
 #define POST_FORM "application/x-www-form-urlencoded"
 #define POST_TEXT "text/plain"
 
+#define COUNT_OF(x) ((sizeof(x)/sizeof(0[x])) / ((size_t)(!(sizeof(x) % sizeof(0[x])))))
+
 typedef QList<QVariantMap> VarMapList;
 
 struct GVRegisteredNumber
 {
-    QString     strId;
-    QString     strName;
-    QString     strNumber;
+    QString     id;
+    QString     name;
+    QString     number;
     char        chType;
 
+    quint64     active              : 1;
+    quint64     verified            : 1;
+    quint64     inVerification      : 1;
+    quint64     reverifyNeeded      : 1;
+    quint64     smsEnabled          : 1;
+    quint64     telephonyVerified   : 1;
+
+    QString     forwardingCountry;
+    QString     displayUnverifyScheduledDateTime;
+
     GVRegisteredNumber () {init();}
     void init() {
         chType = 0;
-        strId.clear ();
-        strName.clear ();
-        strNumber.clear ();
+        id.clear ();
+        name.clear ();
+        number.clear ();
+        active = verified = inVerification = reverifyNeeded = smsEnabled
+               = telephonyVerified = 0;
+        forwardingCountry.clear ();
+        displayUnverifyScheduledDateTime.clear ();
     }
 };
 typedef QVector<GVRegisteredNumber> GVRegisteredNumberArray;
@@ -350,6 +364,8 @@ void qgv_LogFlush();
 #define Q_WARN(_s) qWarning() << QString("%1(%2): %3").arg(__FULLFUNC__).arg(__LINE__).arg(_s)
 #define Q_CRIT(_s) qCritical() << QString("%1(%2): %3").arg(__FULLFUNC__).arg(__LINE__).arg(_s)
 
+#include "NwReqTracker.h"
+#include "PhoneIntegrationIface.h"
 #include "TpHeaders.h"
 #include "AsyncTaskToken.h"
 
